@@ -30,7 +30,19 @@ def safe_root(dotkey):
         return '__ROOT__'
     else:
         return dotkey
-    
+
+
+class Picker():
+    def __init__(self, container, dotkey):
+        self._container = container
+        self._dotkey = dotkey
+        
+    def __getattr__(self, key):
+        return self._container[self._dotkey + '.' + key]
+
+    def __getitem__(self, key):
+        return self._container[self._dotkey + '.' + key]
+
 
 class Container(dict):
     ''' A dictionary-like class that updates observers 
@@ -130,6 +142,13 @@ class Container(dict):
         '''
         self._observers[safe_root(dotkey)].add(view)
 
+    def __missing__(self, key):
+        try:
+            ret = self.get_dct(key)
+        except:
+            return super().__missing__()
+        return ret
+
     def get_dct(self, dotkey):
         ''' Return a dictionary of all key-value pairs for a dotkey prefix 
         
@@ -250,4 +269,12 @@ class Container(dict):
         self.dset(dct, safe=safe)
         yield self
         self.dset(originals, safe=safe)
-        
\ No newline at end of file
+        
+    def get_picker(self, dotkey):
+        return Picker(self, dotkey)
+    
+    def copy(self):
+        return Container(dct=self, name=self.name)
+    
+    def to_dict(self):
+        return dict(self)
\ No newline at end of file
